@@ -1,6 +1,6 @@
 # DHCPy6d DHCPv6 Daemon
 #
-# Copyright (C) 2009-2021 Henri Wahl <henri@dhcpy6d.de>
+# Copyright (C) 2009-2022 Henri Wahl <henri@dhcpy6d.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -557,4 +557,9 @@ class RequestHandler(socketserver.DatagramRequestHandler):
         if command == 'prefix' and len(arguments) == 1:
             cfg.PREFIX = arguments[0]
             volatile_store.store_dynamic_prefix(cfg.PREFIX)
+            # apply dynamic prefix to addresses and prefixes
+            for a in cfg.ADDRESSES:
+                cfg.ADDRESSES[a].inject_dynamic_prefix_into_prototype(cfg.PREFIX)
+            for p in cfg.PREFIXES:
+                cfg.PREFIXES[p].inject_dynamic_prefix_into_prototype(cfg.PREFIX)
         log.info(f'Control message \'{" ".join(control_message_clean)}\' received')
