@@ -78,7 +78,7 @@ class Option(OptionTemplate):
                 response_string_part = self.convert_to_string(self.number, f'{nos_flags:02x}{fqdn_binary}')
             else:
                 # if no hostname given put something in and force client override
-                fqdn_binary = convert_dns_to_binary('invalid-hostname.{cfg.DOMAIN}')
+                fqdn_binary = convert_dns_to_binary(f'invalid-hostname.{cfg.DOMAIN}')
                 response_string_part = self.convert_to_string(self.number, f'{3:02x}{fqdn_binary}')
             # options in answer to be logged
             options_answer_part = self.number
